camerauis/cameraapp/generic/src/CamInfoListBoxContainer.cpp
branchRCL_3
changeset 18 51dda465e618
parent 16 d486e5e3cc9a
child 25 bf64cebf4673
--- a/camerauis/cameraapp/generic/src/CamInfoListBoxContainer.cpp	Wed Mar 31 21:06:44 2010 +0300
+++ b/camerauis/cameraapp/generic/src/CamInfoListBoxContainer.cpp	Wed Apr 14 15:41:04 2010 +0300
@@ -394,10 +394,24 @@
     const TKeyEvent& aKeyEvent,
     TEventCode aType )
     {
+    if( iController.CurrentMode() == ECamControllerIdle || 
+        iController.CurrentMode() == ECamControllerShutdown )
+        {
+        if( !iController.IsViewFinding() && !iSkinnedBackGround
+            && ( IsCaptureKeyL( aKeyEvent, aType ) 
+            || IsShutterKeyL( aKeyEvent, aType ) ) )
+            {
+            PRINT( _L("Camera <> CCamInfoListBoxContainer::OfferKeyEventL coming back from standby" ))
+            ReserveAndStartVF();
+            }
+        return EKeyWasNotConsumed;
+        }
     iController.StartIdleTimer();
-
-    // If the Ok button is pressed, select the current item
-    if ( aKeyEvent.iCode == EKeyOK && aKeyEvent.iRepeats == 0 && aType == EEventKey )
+    
+    // If the Ok button or shutter key is pressed, select the current item
+    if ( ( aKeyEvent.iCode == EKeyOK && aKeyEvent.iRepeats == 0 && aType == EEventKey ) ||
+         ( aType == EEventKeyDown && 
+         ( IsCaptureKeyL( aKeyEvent, aType ) || IsShutterKeyL( aKeyEvent, aType ) ) ) )
         {
         TKeyResponse response = iListBox->OfferKeyEventL( aKeyEvent, aType );
         iView.HandleCommandL( EAknSoftkeySelect );